package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````R"(```````!``````````)"A````
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````"B:````````*)H`````````
M``$```````$````&````0)L```````!`FP$``````$";`0``````0`4`````
M``!H%0```````````0```````@````8```!0FP```````%";`0``````4)L!
M```````@`@```````"`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````3)(```````!,D@```````$R2````````#`$````````,`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````$";````````0)L!``````!`FP$`
M`````,`$````````P`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`4L:AO;J)+@D!N5"A,HCPR/<F
MDW0$````$`````$```!'3E4```````,````'`````````!$```!.````!```
M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(H!!%N@`""$X```!/````
M4@```%8```!7````7P```&````!A````8P```&0```!F````9P```&@```!I
M````;````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5D
MU'S9<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+,!BV]K"4/69Z_,
M9D)%U>R)!W#3#13BGMK-XYXS8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0
MH^#[20`````````````````````````````````````#``L`>!P`````````
M```````````````#`!8``*`!`````````````````)P"```2````````````
M`````````````!,#```2`````````````````````````&P"```2````````
M`````````````````',"```2``````````````````````````4#```2````
M`````````````````````!4"```2`````````````````````````!$````@
M`````````````````````````,0"```2`````````````````````````-P"
M```2`````````````````````````/8"```B````````````````````````
M`-4"```2`````````````````````````+P"```2````````````````````
M`````+0````2`````````````````````````,X"```1````````````````
M`````````(,!```2`````````````````````````$4#```2````````````
M`````````````(0````2``````````````````````````P!```2````````
M`````````````````%X"```2`````````````````````````*H!```2````
M``````````````````````$!```1`````````````````````````*,"```2
M`````````````````````````&<!```2`````````````````````````.,`
M```1`````````````````````````#4!```2````````````````````````
M`!H"```2`````````````````````````"D#```2````````````````````
M`````'H"```2`````````````````````````,(````2````````````````
M`````````+$!```2`````````````````````````.D!```2````````````
M`````````````)X!```2`````````````````````````/$!```2````````
M`````````````````$D"```2`````````````````````````&4"```2````
M`````````````````````"("```2`````````````````````````"L"```2
M``````````````````````````4"```2`````````````````````````$,!
M```2`````````````````````````"T````@````````````````````````
M`&T#```1`````````````````````````#P#```A````````````````````
M`````%$"```2`````````````````````````!L#```2````````````````
M`````````&0````2`````````````````````````(X"```2````````````
M`````````````"(#```2`````````````````````````,`#```2````````
M`````````````````(@"```2`````````````````````````),````2````
M`````````````````````)\````2`````````````````````````%P!```2
M`````````````````````````+$"```2`````````````````````````"(!
M```2`````````````````````````!$!```2````````````````````````
M`%8````2`````````````````````````.P"```2````````````````````
M`````!8!```2`````````````````````````),!```2````````````````
M`````````/`````2`````````````````````````.4"```2````````````
M`````````````'4!```2`````````````````````````',````2````````
M`````````````````-,!```2`````````````````````````%<"```2````
M`````````````````````#L#```1`````````````````````````#T#```1
M`````````````````````````,P!```2`````````````````````````-0`
M```2`````````````````````````%,!```2````````````````````````
M`($"```2`````````````````````````#P````@````````````````````
M`````-@!```2`````````````````````````#P"```2````````````````
M`````````$,"```2`````````````````````````-T#```0`!<`J+`!````
M`````````````,D#```2``T`Z#T```````"```````````$$```2``T`,#,`
M``````"D!@```````#8#```2``T`H"`````````H`@```````(\#```2``T`
M:"P````````$`````````*`#```0`!<`@*`!`````````````````)T$```2
M``T`<"P````````8`@```````-,$```2``T`V#D````````,!````````(D$
M```0`!<`@*`!`````````````````.@#```2``T`B"X````````H````````
M``X$```2``T`@%`````````8`0```````"8$```1``\`V%,````````$````
M`````&4$```0`!<`J+`!`````````````````&H$```0`!<`J+`!````````
M`````````)4$```2``T``"L````````X`````````*H$```2``T`0#(`````
M``#L`````````+P$```2``T`F#$```````"(`````````!D$```0`!8``*`!
M`````````````````/4#```2``T`L"X````````8`0```````-4#```0`!8`
M@*`!`````````````````%L$```1`!8`>*`!```````(`````````'\#```2
M``T`L%,````````$`````````$L$```2``T`,%,```````!\`````````!\$
M```2``T`R"(``````````````````,H$```2``T`*%````````!4````````
M`!L$```@`!8``*`!`````````````````*X#```2``T`(#(````````@````
M`````-P#```0`!<`J+`!`````````````````#4$```2``T`D"L```````#8
M`````````'\$```2``T`F%$```````"4`0```````'($```2``T`R"\`````
M``#,`0````````!L:6)P97)L+G-O+C4N,S``7TE435]D97)E9VES=&5R5$U#
M;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R
M:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R
M;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?
M=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`&QI8G!T:')E860N<V\N,`!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T
M:6]N`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!L:6)C+G-O
M+C8`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL
M:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I9`!S=')D=7``
M<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C
M:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?
M>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D9&ER
M-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S
M<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T
M97)?871F;W)K`&QD+6QI;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K7V-H:U]G
M=6%R9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!?7V)S<U]S
M=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`
M<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I
M;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`
M;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E;G8`<VAA7V9I;F%L
M`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L
M:6)P871H`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?26YT97)N86QS7U!!
M4E]"3T]4`$=,24)#7S(N,3<``````````@`"``(``@`"``(````"``(``@`"
M``(````"`````@```````@`"`````@`````````"``(``@```````P````,`
M`@`"``(``@`#```````$``(``@`"`````@`"``(``@`````````"`````@``
M``(``````````@```````P`"``(``@`#```````"`````P`"``(``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0````$``0!7`P``$````"````"7D98&```$`.D$````````
M`0`!`+P!```0````(````)>1E@8```,`Z00````````!``$`"P(``!``````
M````EY&6!@```@#I!````````$";`0```````P0```````#0(P```````$B;
M`0```````P0```````"((P```````(B?`0```````P0```````"P4P``````
M`-"?`0```````P0````````P4P```````."?`0```````P0```````"@(```
M``````B@`0```````P0````````(H`$``````!B@`0```````P0```````#@
M4P```````""@`0```````P0```````#H4P```````#"@`0```````P0`````
M``#P4P```````#B@`0```````P0`````````5````````$"@`0```````P0`
M```````(5````````$B@`0```````P0````````05````````%"@`0``````
M`P0````````85````````&"@`0```````P0````````@5````````&B@`0``
M`````P0````````H5````````'B@`0```````P0```````"P5P```````)"?
M`0```````00```D``````````````)B?`0```````00```P`````````````
M`*"?`0```````00``!```````````````*B?`0```````00``!$`````````
M`````+"?`0```````00``!<``````````````+B?`0```````00``!H`````
M`````````,"?`0```````00``"H``````````````,B?`0```````00``"L`
M`````````````-B?`0```````00``#@``````````````.B?`0```````00`
M`$$``````````````/"?`0```````00``$4``````````````/B?`0``````
M`00``$H``````````````(B=`0```````@0```,``````````````)"=`0``
M`````@0```0``````````````)B=`0```````@0```4``````````````*"=
M`0```````@0```8``````````````*B=`0```````@0```<`````````````
M`+"=`0```````@0```@``````````````+B=`0```````@0```H`````````
M`````,"=`0```````@0```L``````````````,B=`0```````@0```P`````
M`````````-"=`0```````@0```T``````````````-B=`0```````@0```X`
M`````````````."=`0```````@0```\``````````````.B=`0```````@0`
M`!(``````````````/"=`0```````@0``!,``````````````/B=`0``````
M`@0``!0```````````````">`0```````@0``!4```````````````B>`0``
M`````@0``!8``````````````!">`0```````@0``!@``````````````!B>
M`0```````@0``!D``````````````"">`0```````@0``!L`````````````
M`"B>`0```````@0``!P``````````````#">`0```````@0``!T`````````
M`````#B>`0```````@0``!X``````````````$">`0```````@0``!\`````
M`````````$B>`0```````@0``"```````````````%">`0```````@0``"$`
M`````````````%B>`0```````@0``"(``````````````&">`0```````@0`
M`",``````````````&B>`0```````@0``"0``````````````'">`0``````
M`@0``"4``````````````'B>`0```````@0``"8``````````````(">`0``
M`````@0``"<``````````````(B>`0```````@0``"@``````````````)">
M`0```````@0``"D``````````````)B>`0```````@0``"H`````````````
M`*">`0```````@0``"T``````````````*B>`0```````@0``"X`````````
M`````+">`0```````@0``"\``````````````+B>`0```````@0``#``````
M`````````,">`0```````@0``#$``````````````,B>`0```````@0``#(`
M`````````````-">`0```````@0``#,``````````````-B>`0```````@0`
M`#0``````````````.">`0```````@0``#4``````````````.B>`0``````
M`@0``#8``````````````/">`0```````@0``#<``````````````/B>`0``
M`````@0``#D```````````````"?`0```````@0``#H```````````````B?
M`0```````@0``#L``````````````!"?`0```````@0``#P`````````````
M`!B?`0```````@0``#T``````````````""?`0```````@0``#X`````````
M`````"B?`0```````@0``#\``````````````#"?`0```````@0``$``````
M`````````#B?`0```````@0``$(``````````````$"?`0```````@0``$,`
M`````````````$B?`0```````@0``$8``````````````%"?`0```````@0`
M`$<``````````````%B?`0```````@0``$@``````````````&"?`0``````
M`@0``$D``````````````&B?`0```````@0``$L``````````````'"?`0``
M`````@0``$P``````````````'B?`0```````@0``$T``````````````/U[
MOZG]`P"1H`$`E/U[P:C``U_6`````/![OZG0``"0$<)&^1`"-I$@`A_6'R`#
MU1\@`]4?(`/5T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(VD2`"'];0``"0
M$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y$*(VD2`"'];0
M``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1XD;Y$`(WD2`"
M'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM```)`1[D;Y$&(W
MD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?UM```)`1^D;Y
M$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1(`(?UM```)`1
M!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D08CB1(`(?UM``
M`)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:1_D0PCB1(`(?
MUM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```D!$F1_D0(CF1
M(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6T```D!$R1_D0
M@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@`A_6T```D!$^
M1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B.I$@`A_6T```
MD!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'^1"".I$@`A_6
MT```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0$5Y'^1#B.I$@
M`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0``"0$6I'^1!"
M.Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"'];0``"0$79'
M^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([D2`"'];0``"0
M$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y$$(\D2`"'];0
M``"0$8Y'^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1ED?Y$*(\D2`"
M']:P``#P$9I'^1#"/)$@`A_6L```\!&>1_D0XCR1(`(?UK```/`1HD?Y$`(]
MD2`"']:P``#P$:9'^1`B/9$@`A_6L```\!&J1_D00CV1(`(?UK```/`1KD?Y
M$&(]D2`"']:P``#P$;)'^1""/9$@`A_6L```\!&V1_D0HCV1(`(?UK```/`1
MND?Y$,(]D2`"']:P``#P$;Y'^1#B/9$@`A_6_7NYJ?T#`)'S4P&IM```\(/F
M1_GU6P*I]QL`^>*'!*GB(P&19`!`^>0W`/D$`(#2X4,!D>!?`+G@<P&1B?__
MEZ```/"B``#P`/1'^4+L1_GA`P*JL0P`E*```/``W$?Y``!`.4`*`#33``"0
MM0``\+7:1_F@`D"Y4O__EP)H4CE"`!\R`F@2.:`"0+E-__^7`FA2.4(``#("
M:!(YX%]`N0`4`!$`?'V30O__E^4K0/GC`P"JP0``D&`B`I$"``#P0J`>D2<\
M0/D$``#PI@!`^8$`@%*$@!Z19A``J>8`@)(!!`"Y(0"`T@,$`/EG"`&IXE]`
MN5\$`'$M`0!4'R`#U200`!&@>&'XQ,PDBR$$`)%?``%K8&@D^$S__U1%$``1
M=B("D4(,`!$!``"09<PEBR'@+)'`#D#Y!`"`TK^`'_A\__^7]0,`*J`$`#1V
M(@*1]Y,!D<`.0/GV_O^7````\.$#%ZH`@!21=```E``$`+1S(@*18`Y`^=[^
M_Y=A__^7E.9'^>$W0/F``D#Y(```RF`$`+7@`Q4J\U-!J?5;0JGW&T#Y_7O'
MJ,`#7];Y_O^7TP``D&(B`I%`#`#Y(`,`M+4``/#'_O^7H-I'^0``0+G\_O^7
M'\0H.:;__Q?`#D#Y=/__E_4#`"K9__\7P`I`^6```+35!@"4WO__%^$#%ZH`
M``#P`*`2D4P``)3`"@#Y`/O_M,T&`)36__\7^?[_ER``@%*/_O^7'0"`TAX`
M@-+E`P"JX0-`^>(C`)'F`P"1H```\`#P1_FC``#P8^A'^:0``/"$Q$?YPO[_
ME_G^_Y>@``#P`.!'^4```+3Q_O\7P`-?UA\@`]7```"0```"D<$``)`A``*1
M/P``Z\```%2A``#P(<A'^6$``+3P`P&J``(?UL`#7];```"0```"D<$``)`A
M``*1(0``RR+\?]-!#(&+_P>!ZR'\09/```!4H@``\$+\1_EB``"T\`,"J@`"
M'];``U_6_7N^J?T#`)'S"P#YTP``D&`"0CE``0`UH```\`#,1_F```"TP```
MD``$0/E?_O^7V/__ER``@%)@`@(Y\PM`^?U[PJC``U_6WO__%Q\@`]7]>[RI
M_0,`D?-3`:F@!@"T]V,#J?<#`*J@``#P`/A'^1@`0/DX!@"T]5L"J?8#`:H5
M`(!2X`)`.1_T`'$$&$!ZP0(`5!,#0/G3`0"TM7Y`D_0#&*H?(`/5X@,5JN$#
M%ZK@`Q.J;?[_EX```#5@:G4X'_0`<0`"`%23CD#X\_[_M?5;0JGW8T.IX`,3
MJO-30:G]>\2HP`-?UO4#%ZJ@'D`X'_0`<0080'JA__]4M0(72^7__Q>4`AC+
MM08`D7,"%8N4_D.3U`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HP`-?UA,`@-+I
M__\7$P"`TO=C0ZGF__\7'R`#U?U[O*G]`P"1]5L"J;8``/#UTP"1P>9'^?-3
M`:FT``#P\P,`JB``0/G@'P#Y``"`TI3Z1_GA`Q6JX`,3JK/__Y<``@"TA`)`
M^>4W@+F"#`6+0P1`^8-X)?CC_O^T'R`#U4,(0/E#!`#Y0B``D:/__[7A`Q6J
MX`,3JJ3__Y=`_O^UUN9'^>$?0/G``D#Y(```RJ```+7S4T&I]5M"J?U[Q*C`
M`U_62_[_E_U[N:G]`P"1\U,!J;0``/#S`P"J]5L"J?4#`:KW8P.I^6L$J8'F
M1_F@`D`Y(@!`^>(W`/D"`(#2'_0`<;46E9K@`Q6JR?W_E_<#`*KADP&1X`,3
MJH/__Y=@"`"T]@,`JL+]_Y<?`!?K`@<`5/AG@+FY``#P&/-]TV`"0#D?]`!Q
M!!A`>J`,`%3C`Q.J'R`#U6(<0#A?]`!Q1!A`>J'__U1C`!/+8WQ`DSG[1_G@
M"@"1```#BS<#0/G@_?^7X&HX^,`+`+3C9X"YX`,3JB(#0/D!%$`X0WAC^#_T
M`'$D&$!Z80``.<```%0"%$`X8AP`.%_T`'%$&$!Z@?__5*$'@%(``(#2810`
M.*)J8#AB:"`X``0`D:+__S4``(!2E.9'^>(W0/F!`D#Y00`!R@$(`+7S4T&I
M]5M"J?=C0ZGY:T2I_7O'J,`#7]8!`(#2'R`#U:)J83C":B$X(00`D:+__S7N
M__\7N0``\/LK`/D@^T?Y&P!`^6`#0/E`!0"TX`,;JA8`@%(?(`/5`8Q`^.(#
M%BK6!@`1H?__M4`,`!$`?'V3P0``D"*(0+E"`@`U(@"`4B*(`+FA_?^7^@,`
MJL`#`+38?GV3X0,;JN(#&*I?_?^7(?M'^<!^0),Z``#Y``0`D5][(/CV9P"Y
M^RM`^:/__Q?A`P"JX`,;JL#]_Y?Z`P"J(?M'^2```/E@`0"TP'Y`D]A^?9/R
M__\7`P"`TJ/__Q<``H#2%@"`4M[__Q?[*P#YOOW_E_LK0/D``(`2N/__%_U[
MLJG]`P"1]5L"J;4``/"AYD?Y(@!`^>)O`/D"`(#2P```M/-3`:GT`P"J`0!`
M.4$!`#7S4T&IM>9'^>%O0/F@`D#Y(```RB`)`+7U6T*I_7O.J,`#7];W8P.I
M3_W_E_<#`*J`!P"T&```\!@#$9'Y:P2I^F,!D=G%A5+@`Q>JWOW_ER`%`+0!
M,$%X$TP`D3^X`'%`__]4/P`9:V`%`%3@`Q2J(?W_E_8#`*K@`Q.J'OW_E\`"
M``L`"``1`'Q`DT[]_Y?E`Q.JY`,4JN,#&*KS`P"J`@"`DB$`@%(7_?^7X@,:
MJN$#$ZH``(!2&_W_EQ\$`#&@``!4X&M`N0`,%!(?$$!QX`(`5.`#$ZKO_?^7
MX`,3JK']_Y?@`Q>JM_W_ET#[_[4?(`/5X`,7JFO]_Y?@`Q2JE?W_E_-30:GW
M8T.I^6M$J;W__Q=@"D`Y@/G_--3__Q?S4T&I]V-#J;?__Q?@`Q.JI___E^K_
M_Q?S4P&I]V,#J?EK!*E<_?^7'R`#U?U[M:GA`P"J_0,`D?-3`:FS``#P]`,`
MJF/F1_GBHP"1``"`4F0`0/GD5P#Y!`"`TH;]_Y?@`0`UX3M`N0(`E%(A#!02
M/Q!`<2000GI@`0!4<^9'^>)70/EA`D#Y00`!RH$!`+7S4T&I_7O+J,`#7]8`
M`(!2]___%^`#%*I!`(!23OW_EQ\``''@%Y\:\?__%S;]_Y<?(`/5#`J"TO]C
M+,O]>P"I_0,`D?-3`:FS``#P8N9'^?5;`JGV(P&1]V,#J?4#`*KW`P&J0`!`
M^>`G"/D``(#2X0,6J@```/#B_X'2`"`1D<'\_Y<?``!QK04`5`($`%&A``#P
M(=A'^</*8C@X`$"Y0P,`-0($`#14?$"3X`,6JN(#%*KA!8!2<_W_ET`#`+3@
M`Q@J`/W_E^,#%*KB`Q:JX0,5JG3]_Y=SYD?YX2=(^6`"0/D@``#*P`,`M0P*
M@M+]>T"I\U-!J?5;0JGW8T.I_V,LB\`#7];B`P`JX06`4N`#%JI4?$"3X@,4
MJEK]_Y<`_?^UX`,8*N?\_Y?B`Q>JX0,5JL3\_Y?H__\7H```\`#81_D8`$"Y
MX`,8*M[\_Y?B`Q>JX0,5JKO\_Y??__\7Z?S_E_U[OZF@``#P_0,`D0#81_D`
M`$"YT_S_E_U[P:BB``#P(P``\`$``/!"U$?Y8V`(D2%@$9$/_?\7_7N^J?T#
M`)'S"P#YLP``\'/:1_E@`D"YQ/S_E^O__Y=@`D"YP?S_E_,+0/D$``#P_7O"
MJ(1@'I'C`P2J`@``L`$``/!"8">1(>`1D04`@%(6_?\7'R`#U0P*A-+_8RS+
M``B"TOU[`*G]`P"1\U,!J;0``/#SXP"1]5L"J?9C((L5`(#2@.9'^0$`0/GA
M)Q#Y`0"`TG7\_Y?D`P`J!0``\`,``/"E0!*18V`2D2(`@M(A`(!2X`,3JD#\
M_Y?@`Q.JX0,6J@(`@M)(_/^7@`'X-_,#`*H`!``1`'Q`DV?\_Y?U`P"JP```
MM'-^0)/A`Q:JX@,3JB'\_Y>_:C,XE.9'^>$G4/F``D#Y(```R@`!`+7@`Q6J
M#`J$TOU[0*GS4T&I]5M"J?]C+(O``U_6C_S_E\K__Q<?(`/5#!Z"TO]C+,O]
M>P"I_0,`D?EK!*FZ``#P0N='^?-3`:GS`P&J]5L"J>&3`9'U`P"J0P!`^>-W
M"/D#`(#2````\`"@$I')_?^7]`,`JN$%@%+@`Q6JR_S_ET`"`+3A`Q6J````
M\`#@$I$H_O^7X`,5JEKG1_GB=TCY00-`^4$``<IA#`"U#!Z"TOU[0*GS4T&I
M]5M"J?EK1*G_8RR+P`-?UN`#%:KW8P.I\OO_EQ<``/#X`P`JX2(3D>`#$ZKI
M^_^7\P,`J@`*`+09``#P]J,#D3E#$Y'[*P#Y&P``\'NC#Y%@`D`Y(`8`-+0`
M`+3A`Q.JX`,4JF_\_Y>`!``TX`,3JMS[_Y?B`P`J8,(@BP#P7S@?O`!QX0``
M5$($`%%@PB*+?\HB.`#P7S@?O`!Q8/__5``'`!$"``(+7_P_<0P#`%3D`Q.J
MY@,5JN4#&:H#``#P8V`3D0(`@M(A`(!2X`,6JLC[_Y?BHP&1X0,6J@``@%+,
M^_^7H```->![0+D`#!02'R!`<6`"`%3A(A.1``"`TK3[_Y?S`P"J0/K_M?=C
M0ZG[*T#YKO__%Y0``+2``D`Y'[@`<8```%3S`QNJ(@"`4MS__Q>`!D`Y`/[_
M-/O__Q?@`Q:J(0"`4BK\_Y=@_?\UX0,6J@```/``X!*1Q_W_E^`#%JH'_/^7
M]V-#J?LK0/F<__\7]V-#J97__Q?W8P.I^RL`^0?\_Y<"`$`YX0,`JN(``#0?
M(`/5(00`D5^\`'$`$(&:(@!`.8+__S7``U_68`@`M/U[OJG]`P"1\PL`^?,#
M`*H!`$`YH08`-(7[_Y<"!`#18@("BW\"`NNC``!4-```%$($`-%_`@+KX`$`
M5$``0#D?O`!Q8/__5'\"`NN"!0!40@0`T7\"`NO@``!40`!`.1^\`''@`0!4
M0@0`T7\"`NMA__]40`!`.1^\`'%@`P!4\PM`^0```/#]>\*H`$`3D<_[_Q=`
M`$`Y'[P`<8$``%1"!`#1?P("ZV/__U1"`!/+``"`TD$(`)$_!$#Q"`$`5,``
M`)`$H`*10@0`D>$#$ZK@`P2J`P""THW[_Y?S"T#Y_7O"J,`#7];S"T#Y````
M\/U[PJ@`H`^1M?O_%W\"`NL!_?]4W/__%P```/``H`^1K_O_%_U[N*DA``#P
M(6`(D?T#`)'S4P&ILP``\````/!CYD?Y]5L"J0"`$Y'W8P.I%@``\!<``/!F
M`$#YYC\`^08`@-(8``#0)AQ!J>8?!:D4``#0)!1"J>07!JDA8$!YX>,`>90"
M%9'U,P&1*/W_EP```-``P!.1)?W_EP```-``X!.1(OW_EP```-``(!21'_W_
ME\!"%)$=_?^7````T`"`%)$:_?^7X*(2D1C]_Y<`PQ21%OW_E^`#%*H4_?^7
M````T`!`%9$1_?^7````T`#@$I$._?^7````T.$#%:H`@!61S/S_EX```+3A
M`P"JX`,4JC#]_Y?A`Q6J````T`#@%9'$_/^7X0,`JH```+0```#0`,`/D2?]
M_Y?A`Q6J````T`!`%I&[_/^7X0,`JB`"`+3@HA*1'_W_E\!"%)$!``#0(2`7
MD1O]_Y=SYD?YX3]`^6`"0/D@``#*@`,`M?-30:GU6T*I]V-#J?U[R*C``U_6
MX0,5J@```-``@!:1I?S_E^$#`*J```"T`,,4D0G]_Y?J__\7`"J(TN(31OA`
MZJOR8(C)\J`HZ/)?``#K8?S_5.*31GC`J8=27P``:^'[_U3AKP&1\?__%T3[
M_Y<?(`/5_7N]J?T#`)'S4P&ILP``T+0``/!AYD?Y@!)`N2(`0/GB%P#Y`@"`
MTA\$`#$@`0!4<^9'^>(70/EA`D#Y00`!RB$"`+7S4T&I_7O#J,`#7];ADP"1
M````T`#`%)%Y_/^7X0,`J@``@%*A``"T(`!`.1_``'$$&$!ZX`>?&H`2`+GL
M__\7(?O_E_U[OZG]`P"1QOK_ET'[_Y=```"T``!`^?U[P:C``U_6_7N[J?T#
M`)'S4P&ILP``T.$3`9%BYD?Y]5L"J18``-#W&P#YUT(7D?4#`*K@`Q>J0P!`
M^>,G`/D#`(#25_S_EX```+0!`$`Y]`,`JL$!`#7A`Q6JP$(7D;C\_Y=SYD?Y
MX2=`^6`"0/D@``#*X`,`M?-30:GU6T*I]QM`^?U[Q:C``U_6X0,5JF;[_Y>`
M_O^UX`,5JH/Z_Y?V`P"JX`,4JH#Z_Y?``@"+``@`D;'Z_Y?F`Q2JY`,5J@4`
M`-`#``#0I2`3D6-@$Y$"`("2]`,`JB$`@%)W^O^7X0,4JN`#%ZJ6_/^7WO__
M%][Z_Y<?(`/5##:0TO]C+,NB``#P0D``D?U[`:G]0P"11IQ`J?5;`ZFU``#0
M\U,"J?3S`9&AYD?Y]V,$J?<#`*K@(T"1YA\(J20`0/D$U`#Y!`"`TDHL0JD8
M``#02"1#J>$#%*I$%$2I`*,2D48<1:GFGPFI3`Q`^>Q+`/E",$#YXE<`^>HO
M"ZGH)PRIY!<-J0C\_Y>```"T`0!`.?,#`*H!%0`U^6L%J93__Y?Y`P"J(!``
MM.`#&:I`^O^7`/A_TP`$`)%Q^O^7)`-`.?8#`*J$`0`T&@``T/,#%JI:HQ>1
MX`,3JN,#&JH"`("2(0"`4C;Z_Y=S"@"1)!]`."3__S4!``#0^>,"D2#`#Y$#
M```4((=`^&`)`+3A`Q2JY?O_E_,#`*I@__^T`0!`.2'__S0X_?^7X/[_-.`#
M$ZJ'^O^7\P,`JN`'`+3@`Q.J&_K_E_H#`*K@`Q:J&/K_EUH#``M:$Q`1&0``
MT%I_0)/@`QJJ1OK_E^<#%JKD`Q.J)4,3D08``-`#``#0QL`7D6/@%Y$"`("2
M]@,`JB$`@%(+^O^7X`,6J@$X@%+P^O^7'P0`,:$``%3E^O^7!0!`N;]$`'&!
M"@!4XH,#D>$#%JH``(!2HOK_E_,#`"J`!0`TH```T.0#%JKC`D#Y`@``T`#0
M1_E"(!F1(0"`4A0`@-(``$#Y>OK_E_EK1:G@(T"1M>9'^0'40/F@`D#Y(```
MRB`D`+7@`Q2J##:0TOU[0:GS4T*I]5M#J?=C1*G_8RR+P`-?UOH#`I$9`(!2
M4]MY^+,!`+1@`D`Y8`$`-#D'`!'@`Q.J[/S_ER#__S3@`Q.J._K_E_,#`*J@
M]O^U4]MY^+/^_[43`(#2L?__%^#S0+D`#!02'Q!`<4'Z_U3[<P:I^_M`N=[Y
M_Y=_`P!K8`4`5/MS1JG+__\7]F,"D1,`@%(?(`/5P-IS^(`!`+3A`Q2J<P8`
M$7C[_Y=@__^T`0!`.2'__S0>^O^7^0,`JF#N_[7`VG/XP/[_M:`!@-+D^?^7
M&0``T/8#`*HY@Q>19`J`4G+__Q>@``#0Y`,6JN,"0/D"``#0`-!'^4(@&)$A
M`(!2%`"`T@``0/DM^O^7^6M%J;/__Q?V_O^7X`,3J@3Z_Y?T`P"JKO__%^#S
M0+D`(``2'P`'<6'Z_U3@`QJJR/G_E^$#%*KT`P"J````T`"`&I%-^_^7``L`
MM/H"0/GT^?^7X0,`JN`#&JIM_?^7^P,`JB`*`+3@`QNJA?G_E_H#`*H?#`!Q
M#0(`5`!\0),!``#0`!``T2&@&I%@`P"+#/K_ER`!`#5?$P!QH!``5$`3`%%@
MPR"+`/!?.!^\`'$`$`!4'R`#U:#^_Y?````UX`,;J@$`@%)"^O^7]P,`*@`'
M`#4!``#0(2`7D0```-``P!21C?O_ESE#$Y&5^?^7%P``T`<``-#G8!Z1Y@,`
M*OH#!ZKE`QFJY`,6JN`#%*H#``#0`@"`DF,@&Y$A`(!2]V(;D5OY_Y<1```4
M.?K_EP``0+D?1`!Q00(`5('Y_Y?Z`P#Y<P8`$>8#`"KG`Q,JY0,9JN0#%JKC
M`Q>JX`,4J@(`@)(A`(!22OG_E^`#%*H!.(!2+_K_EQ\$`#&`_?]4X`,6JNOY
M_Y?A`Q2J`*,2D6+[_Y?@`Q2JDO[_E_EK1:G[<T:I2___%_L"0/FO__\70@"`
M4B$"@)+ZHP:1B?G_E^$#&JK@`Q<JP@"`TOGY_Y?@HT8Y@```->"G1CD?#`%Q
M0`@`5`(`@%(!`(#2X`,7*GSY_Y?U!0"4\P,`J@4``!3B`P`JX0,:JN`#$ZH%
M!@"4X0,:JN`#%RH"`)#2Y?G_EQ\``''L_O]4X`,7*OSC!9&(^?^7&@``T.$#
M$ZJ;HP"1\P,<JEJC%Y'W@P61X`,7JCH&`)0?(`/5Y!9`..`#$ZKC`QJJ<PH`
MD0(`@)(A`(!2"/G_EW\#$^L!__]4Y@,<JB5#$Y'D`Q:JX`,4J@<``-`#``#0
MYV`>D6/@&I$"`("2(0"`4O^#!CGZ^/^7M?__%_<&0/DW\/^TX`,7JO'X_Y<?
M#`#QJ>__5``0`-$!``#0X`(`BR'`&I%Z^?^7'P``<7L3EYIU__\7X*M&.1\$
M`7&A]_]4X*]&.1\,`7%!]_]4X+-&.1\@`7'A]O]4X+=&.1\4`7&!]O]4X`,7
M*D(`@%(A!X"2+_G_E^$#&JK@`Q<J(@6`TI_Y_Y?F`QJJ)4,3D>0#%JK@`Q2J
M!P``T`,``-#G8!Z18^`:D0(`@)(A`(!2S/C_EX?__Q?Y:P6I^W,&J33Y_Y<?
M(`/5_7NXJ:```-#]`P"1]V,#J;<``-#S4P&I]-I'^?5;`JGUTP&1`>1'^?EK
M!*F``D"Y(@!`^>(_`/D"`(#2]3<`^1+Y_Y?S`P"J@`)`N0_Y_Y?B`P"J8^)"
M.0```-#A`Q6J`$`4D4/D`CEF^O^7@```M`$`0#D_Q`!QH!,`5%W]_Y?VVD?Y
MP`)`N0#Y_Y<!``#08P&`4B'`&Y$B`(!2$_G_EV`6`+2A``#P-2`"D0`(0/GA
M,P#YH09`N=H"0+D_!`!Q&!1`^0T&`%09@(!2%`"`4C,`@%(9!*!R^W,%J0H`
M`!1A"$#YX`,<JACY_Y>A!D"Y(`0`-7,&`!&4!@`1?P(!:ZH#`%3@`QHJX/C_
MEX)^0)/A`QBJ`P"`4D3Y_Y?[`P"JX!(`M`,`0/FD!D#Y8`Q`N=H"0+D``!D*
M'P`0<9S8<_@`_?]4X`,:*M#X_Y=A`T#Y0P"`4@(`@-*\^/^7X0,`JN`#'*KY
M^/^7V@)`N:$&0+D@_/\T(`0`41\`%&O@"P!4^W-%J>`#&BK`^/^78P"`4@$`
M`-`B`(!2(>`;D=/X_Y?S`P"JH`$`M/3:1_F``D"YMOC_EV$*0/D"``#00@`<
MD2$`0/F1^/^78`I`^0``0/D`#$"Y@`^P-_3:1_F``D"YJOC_EP$``-!C`(!2
M(2`<D2(`@%*]^/^7\P,`JJ`!`+3A-T#Y````T`#@$I']^?^7]0,`JH`"0+E5
M#`"TF_C_EV$*0/GB`Q6J(0!`^7?X_Y?WVD?YX#-`^10@`I'@`D"YDOC_E_,#
M`*K@`D"YC_C_ER(`@%(!``#0(4`<D<?X_Y<"``#0X0,`JD*@')'@`Q.J9OC_
ME^`"0+F$^/^7X@,`JN$W0/D```#07^0".0"@$I'<^?^7@`H`^?,#`*I@!0"T
M`3B`4N`#$ZH$^?^7`00`$3\$`'$$B%%Z80D`5*```-`:Y$?YX3]`^4`#0/D@
M``#*8`@`M?-30:GU6T*I]V-#J?EK1*G]>\BHP`-?U@`$0#F`[/\T8O__%S\$
M`'$M]/]4X#-`^3,`@%+UVD?Y%"`"D0(``!2Z`D"YX`,:*EOX_Y?A`QBJ&?C_
MEX`&0+ES!@`1'P`3:PS__U3@VD?Y^W-%J1H`0+F0__\7@`9`^8/]_Y>`"@#Y
M\P,`JD#Z_[4```#0`,`<D?MS!:F(^/^7H```\-H"0+G@,P#Y@___%^`S0/GA
MVD?Y`"`"D3H`0+D!!$"Y(`0`41\`%&M![_]4U___%SKX_Y?@,T#Y8@I`^0`@
M`I$!!$#Y0`!`^2$`0/D/^_^7G/__%X`"0+DP^/^780I`^2$`0/F%^/^7@/__
M%_MS!:DZ^/^7X3-`^?MS!:GC`P`J/"`"D0```-#B`Q.J`&`=D8$'0/DA`$#Y
M8/C_EQ\@`]7]>[ZI_0,`D?-3`:GT`P"J+OS_EP$`0#GS`P"JP0``-``$`)$_
MO`!Q<Q*`F@$`0#F!__\UW_S_EY\"`/$$&$!Z@0``5/-30:G]>\*HP`-?UH`"
M0#F`__\T`0``T.`#$ZHAP!>1@@"`TNCW_Y?`_O\UX`,4JO-30:G]>\*H5?K_
M%_^#"M&F``#0XF,`D07@`)$)X`&1Y`,"JOU[`*G]`P"1P>1'^2,`0/GC3P'Y
M`P"`TJ$`0+F$0`"1HX1`^"$(P%J!`!_X/P$%ZV'\8--H_&C3"!UXDB?<>-,A
M'`A3YQQPD@/A0ZHA``>J(0`#JH&`'_@!_O]410`(D4$`0/E"(`"10P1`^40<
M0/EC``'*03!`^2$`!,HA``/*(_Q?TV$$`:HA?$"203P`^5\`!>MA_O]4!21`
MJ2LSC]('($&I2U"K\N,/0/DD=)W2HOQ;TZW\0M-"%`6J8P`+BP$!!\JM>06J
M(0`)BB3;K?(A``C*(D`BBR']0M,A>`FJ0@`#BPH00/DO?$"2[`$'RB$`#<KC
M$T#Y0@`*"XP!!8HA``**C`$'RF,`"XN,`0B+4?Q;TS$6`JJ,`0.+\A=`^8,!
M$8M>_$+3(0`/RE(""XMN?!M3(0`'BW!\>]/#>P*JC`$1"R$`$HL0`@ZJH@$#
MRBX`$(OR&T#YL7U`DD(`#(J>_4+30@`1RDT""XM"``^+SWU[T\Y]&U-"``V+
M[P$.JLQ[#*I.``^+0@`/"_*_0ZDA`!`+;0`,RG!\0)*M`0&*/OQ"TZT!$,K!
M>P&JK0$1B]%]>]-#`@N+SGT;4ZT!`XN#`0'*DGU`DF,``HHQ`@ZJ8P`2RJX!
M$8MC`!"+[P$+BTS\0M-O``^+HP$1"X)Y`JK0?7O3SGT;4SY\0)(0`@ZJ+``"
MRF'\0M/M`1"+C`$#BB-X`ZKA`1`+C`$>RNZ_1*F,`1*+L7U[TZU]&U,Q`@VJ
M4GQ`DC#\0M/.`0N+C@$.BTP``\K-`1&+C`$!BHP!$LH!>@&JX@$+BXP!'HNO
M?1M3L'U[TQ`"#ZJ-`0*+P@$1"VP``<KO+T#YK@$0BWY\0)*,`0**C`$>RE'\
M0M,B>@*JXP$+BXP!$HO/?1M3T7U[TXX!`XLQ`@^JHP$0"RP``LK-`1&+[S-`
M^3)\0)*,`0.*</Q"TXP!$LH#>@.JX0$+BXP!'HNO?1M3L'U[TQ`"#ZJ-`0&+
MP0$1"TP``\KO-T#YK@$0BUY\0)*,`0&*C`$>RC'\0M,A>@&JX@$+BXP!$HO/
M?1M3T7U[TXX!`HLQ`@^JH@$0"VP``<K-`1&+[SM`^7)\0)*,`0**4/Q"TXP!
M$LH">@*JXP$+BXP!'HNO?1M3L'U[TQ`"#ZJ-`0.+PP$1"RP``LKO/T#YK@$0
MBSY\0)*,`0.*C`$>RG'\0M,C>@.JX0$+BXP!$HO/?1M3T7U[TXX!`8LQ`@^J
MH0$0"TP``\K-`1&+[T-`^5)\0)*,`0&*,/Q"TXP!$LH!>@&JX@$+BXP!'HNO
M?1M3L'U[TQ`"#ZJ-`0*+P@$1"VP``<KO1T#YK@$0BWY\0)*,`0**C`$>RE'\
M0M,B>@*JXP$+BXP!$HO/?1M3T7U[TXX!`XLQ`@^JHP$0"RP``LK-`1&+[TM`
M^3)\0)*,`0.*</Q"TXP!$LH#>@.JX0$+BXP!'HNO?1M3L'U[TQ`"#ZJ-`0&+
MP0$1"TP``\I1?$"2K@$0BXP!`8HB_$+3C`$1RD%X`:J,`1*+TGU[T\Y]&U.B
M`1`+4@(.JN^[2:E0_$+3[P$+B\X!"XN/`0^+;``!RNT!$HMC?$"2C`$"B@)Z
M`JJ,`0/*[P$2"XP!$8NP?7O3L7T;4RT``LKR5T#Y$`(1JHX!#HLQ?$"2K0$/
MBLP!$(NM`1'*_OU"TT$""XO/>P^JK0$#BY)]&U.M`0&+@VD;4\$!$`M,``_*
M\%M`^4)\0)*,`0&*8P`2JHP!`LH0`@N+BP$1BZX!`PMK`1"+,?Q"T_!?0/DA
M>@&JHP$#B\S]6]/M`0'*C!4.JJT!`TH#`@2+T/U"TY(!"PL.>@ZJ;$$LBRL`
M#LJM`0*+;`$,2D+^6]./02^+3/Y"TZT!`XM"%!*JDGD2JE``#0OC,TRIHD$B
MB\T!$LJB`0)*#?Y"TT%`(8MK``2+`_Y;TV,4$*KK`0N+L'D0JF\`"PMC02.+
M2P(0RF,!`TJ,`02+;D`NB^+]6]/C_4+3+``,BT(4#ZIO>`^JX0]-J5$`#`N"
M02*+#`(/RH(!`DHM_D+3*P`$BR'^6]-L``2+RP$+BR$4$:I#0#*++@`+"V,`
M#(OL<T#YPOU;T[%Y$:I"%`ZJ84$ABXL!!(O,_4+34@`#"XYY#JKM`1'*['=`
M^:$!`4IB0"*+(P(.RBU`,(MB``)*0?Y;TZL!"XLA%!*J@P$$BTW^0M-,0"^+
M,``+"ZUY$JJ#`0.+84$AB^Q[0/G+`0W*80$!2@+^6],K0#&+0A00JHP!!(L1
M_D+33P`#"S!Z$*IK`0R+8D`BB^Q_0/FC`1#*X?U;TV(``DHA%`^J0T`NBXP!
M!(LQ``L+8P`,B^[]0M/L@T#YSWD/JB+^6]-A02&+"P(/RD(4$:IA`0%*BP$$
MBRS^0M-.``,+D7D1JF)`(HOLAT#YXP$1RBU`+8MB``)*P?U;TZL!"XLA%`ZJ
M@P$$B\W]0M-,0#"+,@`+"ZYY#JJ#`0.+84$AB^R+0/DK`@[*80$!2D+^6],K
M0"^+3?Y"TT(4$JJ,`02+4``#"VL!#(NL>1*J8D`BB^V/0/G#`0S*`?Y;TV(`
M`DHA%!"J0T`QBZT!!(L1_D+3+P`+"S!Z$*IC``V+84$AB^V30/F+`1#*80$!
M2N+]6]-"%`^JJP$$BRU`+HON_4+34@`#"\]Y#ZJK`0N+8D`BB^V70/D#`@_*
M8@`"2D'^6],A%!*J3$`LBZ,!!(M-_D+3,0`+"X,!`XNM>1*J84$AB^R;0/GK
M`0W*(OY;TV$!`4I"%!&J*T`PBXP!!(LP_D+33@`#"VL!#(L,>A&J8D`BB_&?
M0/FC`0S*P?U;TV(``DHA%`ZJ0T`OBS$"!(O/_4+3,``+"^YY#JIC`!&+84$A
MB_&C0/F+`0[*80$!2@+^6],K`@2+0A00JBU`+8L1_D+33P`#"S!Z$*JM`0N+
M8D`BB^NG0/G#`1#*8P`"2N']6],A%`^J8@$$BVM`+(OL_4+3,@`-"X]Y#ZH#
M`@_*H4$ABV$``4I-_D+3(T`NBZYY$JKL-U6I4?Y;TS$6$JIB`0*+2P`1BX0!
M!(ML?7O3:WT;4V,`!(N,`0NJ1``1"^(!#JK+`0\*80`,BT(`!(I"``NJD?Q"
MTXN;E](D>@2J:^.Q\D)`,(NM`0N+,7Q[TR%\&U-"``V+,0(!JF,`#`M!`!&+
M0@`1"^U'5JG,`02JD``."HP!`XJ,`1"J</Q"TP-Z`ZJ,02^+,'P;4R]\>].M
M`0N+[P$0JH$``ZJ-`0V+K`$/BW``!`HA``**,0(+BR$`$*I0_$+3`GH"JB%`
M+HN0?7O3CGT;4Q`"#JHL`!&+H0$/"VT``JKONT#Y40`#"HX!$(NM`0&*K0$1
MJC'\0M,A>@&JI$$DB^T!"XO/?7O3SGT;4XT`#8OO`0ZJA`$0"TP``:HQ``(*
M\+]`^:X!#XN,`02*C`$1JI'\0M,D>@2J@T$CBPP""XO0?7O3SGT;4VP`#(L0
M`@ZJHP$/"RT`!*J1``$*[\-`^8X!$(NM`0.*K0$1JG'\0M,C>@.JHD$BB^T!
M"XO/?7O3SGT;4TT`#8OO`0ZJ@@$0"XP``ZIQ``0*\,=`^:X!#XN,`0**C`$1
MJE'\0M,B>@*J@4$ABPP""XO0?7O3SGT;4RP`#(L0`@ZJH0$/"VT``JI1``,*
M[\M`^8X!$(NM`0&*K0$1JC'\0M,A>@&JI$$DB^T!"XO/?7O3SGT;4XT`#8OO
M`0ZJA`$0"TP``:HQ``(*\,]`^:X!#XN,`02*C`$1JI'\0M,D>@2J@T$CBPP"
M"XO0?7O3SGT;4VP`#(L0`@ZJHP$/"RT`!*J1``$*[]-`^8X!$(NM`0.*K0$1
MJG'\0M,C>@.JHD$BB^T!"XO/?7O3SGT;4TT`#8OO`0ZJ@@$0"XP``ZIQ``0*
M\-=`^:X!#XN,`0**C`$1JE'\0M,B>@*J@4$ABPP""XO0?7O3SGT;4RP`#(L0
M`@ZJH0$/"VT``JI1``,*[]M`^8X!$(NM`0&*K0$1JC'\0M,A>@&JI$$DB^T!
M"XO/?7O3SGT;4XT`#8OO`0ZJA`$0"TP``:HQ``(*\-]`^:X!#XN,`02*C`$1
MJI'\0M,D>@2J@T$CBPP""XO0?7O3SGT;4VP`#(L0`@ZJHP$/"RT`!*J1``$*
M[^-`^8X!$(NM`0.*K0$1JG'\0M,C>@.JHD$BB^T!"XO/?7O3SGT;4TT`#8OO
M`0ZJ@@$0"XP``ZIQ``0*\.=`^:X!#XN,`0**C`$1JE'\0M.!02&+#`(+B]!]
M>]/.?1M3+``,BQ`"#JJA`0\+C@$0BXP!$`LB>@*J[T-=J6T``JI1``,*K0$!
MBJT!$:HQ_$+3(7H!JJ1!)(LQ``(*[0$+B\]]>]/.?1M3A``-B^\!#JI-``&J
MC@`/BZT!#(JM`1&JD?U"TQ`""XNC02.++7H,JM%]>]/.?1M3C``/"V,`$(LQ
M`@ZJ)``-JK`!`0KN\T#Y;P`1BX0`#(J$`!"JD/U"TQ!Z#*J"0"*+Q`$+B^Y]
M>]/O?1M3;``1"T(`!(O.`0^JI`$0JA$"#0KO]T#Y0P`.BX0`#(I.``X+A``1
MJI']0M,L>@RJ@4`ABW%\&U/O`0N+8V@;4R\`#XMC`!&J!`(,JO$!`POC`0.+
MX3]?J8(!$`J$``Z*A``"JH1`+8LM_EO3K141JBL`"XO!_4+3(7@.JH0`"XN"
M`0'*K@$$"T,``TJ-0"V+8D`PB\,ZF-)#3+GR,/Y"T^\!`XO+_5O3$7H1JD(`
M#XMK%0ZJ)``1RN\#0?ER`0(+A``-2DM`*XOM`0.+C$`LB\_]0M-$_EO3[GD.
MJHP!#8N$%!*J(@(.RNT'0?F0``P+2P`+2H1!)(MB02&+K0$#BTO^0M,!_EO3
M<GD2JDT`#8LA%!"JS`$2RN(+0?DO``T+C`$$2@O^0M-$``.+C$$QB^+]6]-P
M>1"JC`$$BT(4#ZKD#T'Y40`,"TL"$,JA02&+80$!2H0``XLK0"Z+[?U"TR'^
M6].O>0^J:P$$BR$4$:KD$T'Y+@`+"X)!(HL,`@_*@@$"2BW^0M.,``.+1$`R
MB\+]6].Q>1&JA``,BT(4#JKL%T'Y30`$"V%!(8OK`1'*80$!2HL!`XLL0#"+
MT/U"TZ']6],.>@ZJC`$+BR$4#:KK&T'Y,``,"X)`(HLD`@[*@@`"2F0!`XM+
M0"^+K_U"TP+^6]/M>0VJ:P$$BT(4$*KD'T'Y3P`+"X%!(8O,`0W*@0$!2HP`
M`XLD0#&+$?Y"T^']6],P>A"JA``,BR$4#ZKL(T'Y,0`$"V)!(HNK`1#*8@$"
M2HL!`XM,0"Z+[OU"TR+^6]//>0^JC`$+BT(4$:KK)T'Y3@`,"X%`(8L$`@_*
M@0`!2F0!`XLK0"V++?Y"T\']6].Q>1&J:P$$BR$4#JKD*T'Y+0`+"X)!(HOL
M`1'*@@$"2HP``XM$0#"+T/U"TZ+]6],.>@ZJA``,BT(4#:KL+T'Y4``$"V%!
M(8LK`@[*80$!2HL!`XLL0"^+K_U"TP'^6]/M>0VJC`$+BR$4$*KK,T'Y+P`,
M"X)`(HO$`0W*@@`"2F0!`XM+0#&+$?Y"T^+]6],P>A"J:P$$BT(4#ZKQ-T'Y
MI`$0RH%!(8M,``L+@0`!2C$"`XLD0"Z+\OU"TX']6]-/>@^JC@`1BR$4#*KQ
M.T'Y!`(/RF)!(HLK``X+@@`"2C$"`XN2_4+30D`MBV3]6]--`!&+A!0+JD)Z
M#*KL/T'Y\0$"RL%!(8N.``T+(0(!2I$!`XLL0#"+</U"T\']6].,`1&+$'H+
MJB$4#JKQ0T'Y2P`0RJ1!)(LM``P+9`$$2C$"`XN+0"^+S_U"TZ3]6]/N>0ZJ
M<0$1BX04#:KK1T'YCP`1"X%!(8L,`@[*C`$!2F$!`XN"02*+Z_U;TT(``8MK
M%0^J2P`+BZ']0M/L2T'Y+7@-JB1")(O!`0W*8GU[TW%]&U,D``1*I4`PBT(`
M$:J#`0.+X?U"TT(`!(LA>`^J8P`%B\;D1_E"``,+)P`'"\H!"@MI`0D+J`$(
M"P(D`*D'(`&IXD]!^<$`0/E!``'*"A``^8$``+7]>T"I_X,*D<`#7]:?\_^7
M_7N_J0`0@-+]`P"17_/_EQ\8`/DF8(32)7&5TL2?F]+#CHK2`CZ<TJ;HK/*E
M^;WR1!>S\D,&HO)">KCR!A0`J00,`:D"?`*I'W@`N?U[P:C``U_6'R`#U?U[
MO*E"?$"3_0,`D?-3`:D4X`"1\P,!JO5;`JGU`P"J]@,"JO=C`ZD%C$*I`'A`
MN:0,`@N_``3K8Y2#FF)T0HNDB@*I(`0`-=_^`'$M!@!4U@(!4==F>I+W`@&1
MV'X&4W<"%XL?(`/58`9`J8`&`*ES`@&18@Y]J8(.`:G@`Q6J8@Y^J8(.`JEB
M#G^I@@X#J5;[_Y=_`A?K@?[_5-8:&$OA`Q>JX`,4JL)^0)/A\O^7MGH`N?-3
M0:GU6T*I]V-#J?U[Q*C``U_6%PB`4O<"`$O?`A=K@,(@B]?2EQKX?D"3X@,8
MJM/R_Y>@>D"YX`(`"Z!Z`+D?``%QX?W_5-8"%TMS`AB+X`,5JCC[_Y?/__\7
M]P,3JN/__Q?]>[RIXP^`$OT#`)'S4P&I]`,`JO,#`:KU6P*I->``D?<;`/D@
M%$#Y-BA`N3<P0+D`(`-3U@K`6@($`!'W"L!:7^``<:/*(#B@PB*+C0D`5`$(
M@%(B``)+`0"`4D)\0),&\_^7X`,3JAK[_Y=__@.I?_X$J7_^!:E_-@#Y=UH.
M*>`#$ZH3^_^780)`^>`#$ZHA_%C3@0(`.6$"0/DA_%#3@08`.6$"0/DA_$C3
M@0H`.6$"0/F!#@`Y809`^2'\6-.!$@`Y809`^2'\4-.!%@`Y809`^2'\2-.!
M&@`Y809`^8$>`#EA"D#Y(?Q8TX$B`#EA"D#Y(?Q0TX$F`#EA"D#Y(?Q(TX$J
M`#EA"D#Y@2X`.6$.0/DA_%C3@3(`.6$.0/DA_%#3@38`.6$.0/DA_$C3@3H`
M.6$.0/F!/@`Y81)`^2'\6-.!0@`Y81)`^2'\4-.!1@`Y81)`^2'\2-.!2@`Y
M81)`^8%.`#GS4T&I]5M"J?<;0/G]>\2H(//_%P$'@%(B``)+`0"`4D)\0).[
M\O^7N___%Q\@`]7]>[RI_0,`D?-3`:FT``"0E"(MD?5;`JFU``"0M0(MD90"
M%<OV`P`J]V,#J?<#`:KX`P*J1?+_E_\/E.M@`0!4E/Y#DQ,`@-*C>G/XX@,8
MJG,&`)'A`Q>JX`,6*F``/]:?`A/K(?__5/-30:GU6T*I]V-#J?U[Q*C``U_6
M'R`#U<`#7]8?(`/5HP``L&,$0/EL\O\7_7N_J?T#`)']>\&HP`-?U@`````!
M``(``````"]T;7``````+@````````!005)?5$U01$E2````````5$U01$E2
M``!414U01$E2`%1%35``````5$U0``````!54T52`````%5315).04U%````
M```````N+@```````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`
M````97AE```````O<')O8R\E:2\E<P``````4$%27U1%35```````````%!!
M4E]04D]'3D%-10`````Z`````````"\`````````)7,E<R5S``!015),-4Q)
M0@``````````4$523$Q)0@!015),-4]05```````````4$523$E/``!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140``````%!!4E]#3$5!3@````````!0
M05)?1$5"54<`````````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?1$5"
M54<``````````%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!005)?0TQ%04X]````````
M,0````````!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````'!A<BT`
M````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P
M87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`
M```E<R5S=&5M<"TE=2TE=25S``````````!!4D=6`````!@`````````<&5R
M;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4P````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````"UE````````+2T```````!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*
M;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@
M)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D
M;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@
M)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H
M=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&
M2"P@)&UA9VEC7W!O<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*
M;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@
M)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M
M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PIP<FEN="`D9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D
M9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA
M;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO
M="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P
M87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO
M9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@
M/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD
M969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U
M:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G
M<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@
M;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D
M9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#
M8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0[
M"GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T
M<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@
M*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS
M92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@
M)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X[
M"F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C
M;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*
M)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI
M.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#
M04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP
M<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E
M;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*
M9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@
M+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60[
M"F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H
M)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D[
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H
M;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD
M8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE
M>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E
M*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL
M97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M
M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A
M;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@
M)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@````!P97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("```````1L#.P@!```@````5([__Y0&``#,D/__(`$``/R0__\T
M`0``/)'__T@!``"$D?__;`$``(R1__^$`0``A)+__^P!```LD___'`(``&R5
M__]L`@``[);__^P"``"$E___%`,``+28__]4`P``[)C__W0#``!$F?__F`,`
M`!R:___0`P``))K__^0#```\G/__4`0``&2<__]D!```?)W__Z`$``!,G___
MV`0``-2?__\`!0``])___R`%``#DH/__5`4``(RG___X!0``G*O__V0&```<
MK/__S`8``-R]___P!@``-+[__Q`'``!,O___2`<``.3`__]\!P``9,'__[`'
M``!LP?__Q`<``!```````````7I2``1X'@$;#!\`$````!@```"DC___,```
M```````0````+````,"/__]``````````"````!`````[(___T@`````00X@
MG02>`T*3`D[>W=,.`````!0```!D````$)#__P0``````````````&0```!\
M`````)#___0`````00Y`G0B>!T*3!I0%0I@!EP)&E@.5!%;6U4'8UT/>W=/4
M#@!!#D"3!I0%E026`Y<"F`&=")X'3];50=C70=[=T]0.`$$.0),&E`6=")X'
M0I<"F`%"V-<`+````.0```"0D/__J`````!!#D"=")X'0I4$E@-$DP:4!6$*
MWMW5UM/4#@!!"P``3````!0!```(D?__0`(```!!#G"=#IX-0I,,E`M#E0J6
M"4N7")@'F0::!0)`"M[=V=K7V-76T]0.`$$+29L$8`K;00M*VT*;!$/;09L$
M0MM\````9`$``/B2__]\`0```$$.X`&=')X;0I48EA='E!F3&D34TT?>W=76
M#@!!#N`!DQJ4&948EA>=')X;09@5EQ9&FA.9%'(*U--!V-=!VME!"T/9VD'4
MTT'8UT&3&I09EQ:8%9D4FA-#T]37V-G:0909DQI!F!67%D&:$YD4`"0```#D
M`0``^)/__Y0`````00ZP`9T6GA5#DQ24$U<*WMW3U`X`00L\````#`(``&B4
M__\P`0```$(.T"!!G8H$GHD$0I.(!)2'!$.5A@26A01"EX0$F(,$:@K=WM?8
MU=;3U`X`00L`'````$P"``!8E?__.`````!!#A"=`IX!1M[=#@`````@````
M;`(``'"5__]4`````$$.()T$G@-"DP)*WMW3#@`````T````D`(``*25___8
M`````$(.T$!"G8H(GHD(0I.(")2'"$.5A@B6A0AK"MW>U=;3U`X`00L``!``
M``#(`@``1);__P0`````````:````-P"```XEO__&`(```!"#O`A09V>!)Z=
M!$*9E@2:E01#DYP$E)L$0Y6:!):9!%P*W=[9VM76T]0.`$$+0IB7!)>8!$R;
ME`1R"MC70=M!"U78UT';09>8!)B7!$'8UT*8EP27F`1!FY0$$````$@#``#D
ME___*``````````X````7`,``/B7__\8`0```$(.()T$G@-"DP)@"M[=TPX`
M0@M4"M[=TPX`00M#"M[=TPX`0@M##@#3W=XT````F`,``-28___,`0```$$.
M@`&=$)X/1),.E`U&E0R6"Y<*F`D"4`K>W=?8U=;3U`X`00L``"0```#0`P``
M;)K__X@`````00XPG0:>!4*3!)0#4`K>W=/4#@!!"P`<````^`,``,R:__\@
M`````$$.$)T"G@%&WMT.`````#`````8!```S)K__^P`````00Y0G0J>"4*3
M")0'1)4&E@5"EP17"M[=U]76T]0.`$$+``"@````3`0``(B;__^D!@```$(.
ML(,"0YVT()ZS($.5L""6KR!"D[(@E+$@0Y>N()BM(%N:JR"9K"`"6-K93=W>
MU]C5UM/4#@!!#K"#`I.R()2Q()6P():O()>N()BM()FL()JK()VT()ZS(%><
MJ2";JB!%W-MCVME&F:P@FJL@FZH@G*D@`F$*VME!W-M!"P)PV=K;W$&:JR"9
MK"!!G*D@FZH@`&@```#P!```C*'__PP$````00Z``9T0G@]#EPJ8"4*3#I0-
M0I4,E@M(F0B:!V><!9L&:MS;`ED*WMW9VM?8U=;3U`X`00M#FP:<!5+<VTH*
MG`6;!D$+1)L&G`5)V]Q0"IP%FP9!"T*<!9L&`"P```!<!0``,*7__X``````
M00X@G02>`T*3`I0!4`K>W=/4#@!!"TO>W=/4#@```#0```",!0``N(?__R@"
M````00YPG0Z>#4*3#)0+1)4*E@F7"`)C"M[=U]76T]0.`$$+````````(```
M`,0%``!(I?__P!$```!!#J`%1IU4GE,#9P0*W=X.`$$+'````.@%``#DMO__
M5`````!!#A"=`IX!4][=#@`````T````"`8``!RW__\8`0```$$.0)T(G@=#
MDP:4!4.5!)8#0Y<"F`%G"M[=U]C5UM/4#@!!"P```#````!`!@``_+?__Y0!
M````00Y`G0B>!T.3!I0%0Y4$E@-"EP("50K>W=?5UM/4#@!!"P`P````=`8`
M`&"Y__]\`````$$.0)T(G@="DP:4!4.5!)8#19<"F`%3WMW7V-76T]0.````
M$````*@&``"LN?__!``````````0````O`8``*"Y__\,````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````T",```````"((P````````$``````````0`````````!````
M`````+P!`````````0`````````+`@````````$`````````5P,````````,
M`````````'@<````````#0````````#$4P```````!D`````````0)L!````
M```;``````````@`````````&@````````!(FP$``````!P`````````"```
M``````#U_O]O`````)@"````````!0````````#`#0````````8`````````
MB`,````````*`````````/0$````````"P`````````8`````````!4`````
M```````````````#`````````'"=`0```````@````````#H!0```````!0`
M````````!P`````````7`````````)`6````````!P````````#P$P``````
M``@`````````H`(````````)`````````!@`````````'@`````````(````
M`````/O__V\``````0``"`````#^__]O`````)`3````````____;P`````#
M`````````/#__V\`````M!(```````#Y__]O`````!``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"0'````````)`<````````D!P```````"0'````````)`<````
M````D!P```````"0'````````)`<````````D!P```````"0'````````)`<
M````````D!P```````"0'````````)`<````````D!P```````"0'```````
M`)`<````````D!P```````"0'````````)`<````````D!P```````"0'```
M`````)`<````````D!P```````"0'````````)`<````````D!P```````"0
M'````````)`<````````D!P```````"0'````````)`<````````D!P`````
M``"0'````````)`<````````D!P```````"0'````````)`<````````D!P`
M``````"0'````````)`<````````D!P```````"0'````````)`<````````
MD!P```````"0'````````)`<````````D!P```````"0'````````)`<````
M````D!P```````"0'````````)`<````````D!P```````"0'````````)`<
M````````D!P```````"0'````````)`<````````D!P```````"0'```````
M`)`<````````D!P```````!0FP$``````+!3````````````````````````
M````````````````````````````````````````````````````````````
M`````````#!3``````````````````"@(```````````````````````````
M````````````````````````"*`!``````#_____`````.!3````````Z%,`
M`````````````````/!3`````````%0````````(5````````!!4````````
M&%0``````````````````"!4````````*%0``````````````````+!7````
M````1T-#.B`H56)U;G1U(#DN,RXP+3$S=6)U;G1U,2D@.2XS+C```"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A
M>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE
M;G0`````````````````````````````````````````````````````````
M````````````````````````````````"P````$````"`````````#@"````
M````.`(````````;`````````````````````0```````````````````!,`
M```'`````@````````!4`@```````%0"````````)```````````````````
M``0````````````````````F````!P````(`````````>`(```````!X`@``
M`````"`````````````````````$````````````````````-````/;__V\"
M`````````)@"````````F`(```````#P``````````4`````````"```````
M`````````````#X````+`````@````````"(`P```````(@#````````.`H`
M```````&`````P````@`````````&`````````!&`````P````(`````````
MP`T```````#`#0```````/0$```````````````````!````````````````
M````3@```/___V\"`````````+02````````M!(```````#:``````````4`
M`````````@`````````"`````````%L```#^__]O`@````````"0$P``````
M`)`3````````8``````````&`````P````@```````````````````!J````
M!`````(`````````\!,```````#P$P```````*`"````````!0`````````(
M`````````!@`````````=`````0```!"`````````)`6````````D!8`````
M``#H!0````````4````5````"``````````8`````````'X````!````!@``
M``````!X'````````'@<````````%`````````````````````0`````````
M``````````!Y`````0````8`````````D!P```````"0'````````!`$````
M```````````````0`````````!``````````A`````$````&`````````*`@
M````````H"`````````D,P``````````````````"```````````````````
M`(H````!````!@````````#$4P```````,13````````$```````````````
M``````0```````````````````"0`````0````(`````````V%,```````#8
M4P```````'(^```````````````````(````````````````````F`````$`
M```"`````````$R2````````3)(````````,`0``````````````````!```
M`````````````````*8````!`````@````````!8DP```````%B3````````
MT`8```````````````````@```````````````````"P````#@````,`````
M````0)L!``````!`FP````````@````````````````````(``````````@`
M````````O`````\````#`````````$B;`0``````2)L````````(````````
M````````````"``````````(`````````,@````&`````P````````!0FP$`
M`````%";````````(`(````````&``````````@`````````$`````````#1
M`````0````,`````````<)T!``````!PG0```````)`"````````````````
M```(``````````@`````````U@````$````#``````````"@`0```````*``
M``````"`````````````````````"````````````````````-P````(````
M`P````````"`H`$``````("@````````*!````````````````````@`````
M``````````````#A`````0```#````````````````````"`H````````"0`
M```````````````````!``````````$``````````0````,`````````````
M````````````I*````````#J`````````````````````0``````````````
$````````
